summaryrefslogtreecommitdiff
path: root/include/apr_file_io.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/apr_file_io.h')
-rw-r--r--include/apr_file_io.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/apr_file_io.h b/include/apr_file_io.h
index dbc8d422d..a33a5dab0 100644
--- a/include/apr_file_io.h
+++ b/include/apr_file_io.h
@@ -107,7 +107,7 @@ extern "C" {
#define APR_FILE_NOCLEANUP 0x00800 /**< Do not register a cleanup when the file
is opened */
#define APR_SENDFILE_ENABLED 0x01000 /**< Advisory flag that this file should
- support apr_sendfile operation */
+ support apr_socket_sendfile operation */
/** @} */
/**
@@ -195,7 +195,7 @@ typedef struct apr_file_t apr_file_t;
* be closed when the pool is destroyed.
* APR_SENDFILE_ENABLED Open with appropriate platform semantics
* for sendfile operations. Advisory only,
* apr_sendfile does not check this flag.
* </PRE>
* @param perm Access permissions for file.
* @param cont The pool to use.
@@ -195,7 +195,7 @@ typedef struct apr_file_t apr_file_t;
* APR_SENDFILE_ENABLED Open with appropriate platform semantics
* for sendfile operations. Advisory only,
- * apr_sendfile does not check this flag.
+ * apr_socket_sendfile does not check this flag.
* </PRE>
* @param perm Access permissions for file.